@@ -1,8 +1,5 @@
 <?php
-include_once(dirname(__FILE__) . "/lib/defines.php");
-include_once(dirname(__FILE__) . "/lib/Class.Table.php");
-
-
+require_once(dirname(__FILE__) . "/lib/defines.php");
 
 getpost_ifset(array('current_page', 'fromstatsday_sday', 'fromstatsmonth_sday', 'days_compare', 'min_call', 'posted',  'dsttype', 'sourcetype', 'clidtype', 'channel', 'resulttype', 'stitle', 'atmenu', 'current_page', 'order', 'sens', 'dst', 'src', 'clid', 'userfieldtype', 'userfield', 'accountcodetype', 'accountcode'));
 
