@@ -1,10 +1,5 @@
 <?
-include_once(dirname(__FILE__) . "/lib/defines.php");
-include_once(dirname(__FILE__) . "/lib/Class.Table.php");
-
-
-// correct 31 +1 = 32 for the date
-//session_start();
+require_once(dirname(__FILE__) . "/lib/defines.php");
 
 getpost_ifset(array('posted', 'Period', 'frommonth', 'fromstatsmonth', 'tomonth', 'tostatsmonth', 'fromday', 'fromstatsday_sday', 'fromstatsmonth_sday', 'today', 'tostatsday_sday', 'tostatsmonth_sday', 'dsttype', 'sourcetype', 'clidtype', 'channel', 'resulttype', 'stitle', 'atmenu', 'current_page', 'order', 'sens', 'dst', 'src', 'clid', 'userfieldtype', 'userfield', 'accountcodetype', 'accountcode', 'duration1', 'duration1type', 'duration2', 'duration2type','purge'));
 
@@ -210,7 +205,7 @@ if ($posted==1){
 	
 	
 	/************************/
-	$QUERY = "SELECT substring(calldate,1,10) AS day, sum(duration) AS calltime, count(*) as nbcall FROM cdr WHERE ".$FG_TABLE_CLAUSE." GROUP BY substring(calldate,1,10)"; 
+	$QUERY = "SELECT substring(calldate,1,10) AS day, sum(duration) AS calltime, count(*) as nbcall FROM ".DB_TABLENAME." WHERE ".$FG_TABLE_CLAUSE." GROUP BY substring(calldate,1,10)"; 
 	//echo "$QUERY";
 	
 	
@@ -315,7 +310,7 @@ case "confirmed":
 	# SQL delete
 	#
 	?><center><?
-	$QUERYD = "DELETE  FROM cdr WHERE ".$FG_TABLE_CLAUSE; 
+	$QUERYD = "DELETE  FROM ".DB_TABLENAME." WHERE ".$FG_TABLE_CLAUSE; 
 	$res = $DBHandle -> query($QUERYD);
 	$numaff = $DBHandle -> affected_rows();
 	?><br>
